import{_ as o,o as c,c as s,a as e,j as t}from"./index-AhVYV2OA.js";const a={},n={style:{"background-color":"#d2d2fa",height:"100vh",display:"grid","place-items":"center"}},r=e("h2",{style:{"text-align":"center"}},[t("欢迎使用"),e("a",{href:"https://github.com/xaoyaoo/PyWxDump.git"},"PyWxDump"),t("聊天记录查看工具! ")],-1),i=e("p",null,"如需提前体验更多功能，请开通超级vip",-1),_=[r,i];function d(h,l){return c(),s("div",n,_)}const f=o(a,[["render",d]]);export{f as default};
