.label_color[data-v-cb8b8fa3]{color:#333;font-size:15px;padding-left:15px;padding-right:0}.data_color[data-v-cb8b8fa3]{color:#08488c;background-color:#f4f4f4;font-size:15px;padding-left:6px;padding-right:6px;font-weight:700;white-space:nowrap;max-width:80%}
